%%
%% Demo 3a: This demo evaluates different techniques for signal subspace determination,
%%          (i.e. provide an estimation of how many endmembers are present in the image)
%%          In particular, we compare PCA, MNF, HFC, NW-HFC and HySime
%%
%%          Main parts of the code belong to the following online toolboxes:
%%              Jose Bioucas-Dias, http://www.lx.it.pt/~bioucas/code.htm
%%              Manuel Grana & Miguel Angel Veganzones, http://www.ehu.es/computationalintelligence
%%
%%          Please acknowledge their usage if used in your work!
%%
%% Gustau Camps-Valls, gcamps@uv.es, http://isp.uv.es
%% 2014(c)
%%

clear;clc;close all;
fontname = 'Arial';
fontsize = 18;
fontunits = 'points';
set(0,'DefaultAxesFontName',fontname,'DefaultAxesFontSize',fontsize,'DefaultAxesFontUnits',fontunits,...
    'DefaultTextFontName',fontname,'DefaultTextFontSize',fontsize,'DefaultTextFontUnits',fontunits,...
    'DefaultLineLineWidth',1.5,'DefaultLineMarkerSize',8,'DefaultLineColor',[0 0 0]);

%% Add some needed funtions to the path
addpath('aux_code/')

%% Load (a small portion of the) Crupite datast

load cuprite_ref.mat
B = length(BANDS);
R = reshape(x',[Lines Columns B]);
R = R(:,:,[176 109 32]);
% figure,imagesc(R),colormap gray,axis off equal
figure,imagesc(decorrstretch(R)),colormap gray,axis off equal
print -depsc figures/cuprite.eps

% PCA
[M_pct, V, D] = hyperPct(x, B);

% MNF
[M, H, snr, VV, DD, snrgus] = hyperMnf(x, Lines, Columns);

figure
plot(1:B,100*cumsum(diag(D))/sum(diag(D)),'k','linewidth',3)
xlabel('Eigenvalue i'),ylabel('Explained variance [%]')
grid
axis([1 13 91 100])
print -depsc figures/pca_cuprite.eps

figure
semilogy(1:B,10*log10(snr),'k-','linewidth',3),hold on
xlabel('Eigenvalue i'),ylabel('SNR [dB]')
grid
print -depsc figures/mnf_cuprite.eps

%% HFC
[qhfc] = hfc(x)

%% NW-HFC
x2 = VV*x;
[qhfc] = hfc(x2)

%% HySime
[B N]=size(x);
verbose='on';
noise_type='poisson';
[w Rn] = estNoise(x,noise_type,verbose);
sel_pixel = round((N-1)*rand(1));

[kf Ek] = hysime(x,w,Rn,verbose);    % estimate the p
fprintf(1,'The signal subspace dimension is: k = %d\n',kf)
print -depsc figures/hysime.eps

