%%
%% Demo 3a: This demo evaluates different techniques for endmember determination/extraction
%%          In particular, we compare classical and advanced methods, belonging to different families: VCA, PPI, NFINDR, SVDD
%%
%%          Main parts of the code belong to the following online toolboxes:
%%              Jose Bioucas-Dias, http://www.lx.it.pt/~bioucas/code.htm
%%              Manuel Grana & Miguel Angel Veganzones, http://www.ehu.es/computationalintelligence
%%
%%          Please acknowledge their usage if used in your work!
%%
%% Gustau Camps-Valls, gcamps@uv.es, http://isp.uv.es
%% 2014(c)
%%

clear;clc;close all;
fontname = 'Arial';
fontsize = 18;
fontunits = 'points';
set(0,'DefaultAxesFontName',fontname,'DefaultAxesFontSize',fontsize,'DefaultAxesFontUnits',fontunits,...
    'DefaultTextFontName',fontname,'DefaultTextFontSize',fontsize,'DefaultTextFontUnits',fontunits,...
    'DefaultLineLineWidth',1.5,'DefaultLineMarkerSize',8,'DefaultLineColor',[0 0 0]);
rand('seed',1234)
randn('seed',1234)

%% Add some needed funtions to the path
addpath('aux_code/')

%% LOAD DATA: Crupite mining site, "cuprite_ref"
load cuprite_ref
B = length(BANDS);
HIM = reshape(x',[ Lines Columns B]);  % hyperspectral image

%% FIX THE NUMBER OF ENDMEMBERS. See J. Nascimento and J. Bioucas-Dias,
%% Vertex component analysis: a fast algorithm to unmix hyperspectral data.
%% IEEE Transactions on Geoscience and Remote Sensing, 43(8), 898-910,
%% 2005.

p=14;

%% SELECT THE ENDMEMBER EXTRACTION METHODS TO BE USED

methods = {'vca','ppi','nfindr','svdd'}
% methods = {'vca'}  % only this
methods_lab = {'VCA','PPI','NFINDR','SVDD'}

%% FILE TO SAVE RESULTS
filename = 'results_endmembers.mat'

clc

%% GEOMETRICAL

% VCA
if find(strcmpi(methods,'vca'))
    t=cputime;
    [A_est, location, y] = vca(x,'Endmembers',p,'verbose','on');
    s_est = (pinv(A_est) * y)';
    endmembers_vca = A_est;
    cputime_vca = cputime-t
end

% PPI
if find(strcmpi(methods,'ppi'))
    t=cputime;
    numSkewers = 5000;
    [endmembers_ppi,indices_ppi] = ppi(x,p,numSkewers);
    cputime_ppi = cputime-t
end

% NFINDR
if find(strcmpi(methods,'nfindr'))
    t=cputime;
    [endmembers_nfindr,indices_nfindr] = nfindr(x,p);
    cputime_nfindr = cputime-t
end

%% STATISTICAL

% SVDD, only with 3000 training samples randomly selected
if find(strcmpi(methods,'svdd'))
    t=cputime;
    [endmembers_svdd, indices_svdd] = svddunmixing(x,p,[-0.5 0.5],3000);
    cputime_svdd = cputime-t
end

save(filename)
